@@ -724,22 +724,14 @@ class CameraDevice(Protocol):
     @property
     def internal_sources(self) -> list[CameraDeviceInternalSource]: ...
 
-    @property
-    def on_connected(self) -> Observable[bool]: ...
-    @property
-    def on_light_switched(self) -> Observable[LightState]: ...
-    @property
-    def on_motion_detected(self) -> Observable[MotionState]: ...
-    @property
-    def on_audio_detected(self) -> Observable[AudioState]: ...
-    @property
-    def on_object_detected(self) -> Observable[ObjectState]: ...
-    @property
-    def on_doorbell_pressed(self) -> Observable[DoorbellState]: ...
-    @property
-    def on_siren_detected(self) -> Observable[SirenState]: ...
-    @property
-    def on_battery_changed(self) -> Observable[BatteryState]: ...
+    on_connected: Observable[bool]
+    on_light_switched: Observable[LightState]
+    on_motion_detected: Observable[MotionState]
+    on_audio_detected: Observable[AudioState]
+    on_object_detected: Observable[ObjectState]
+    on_doorbell_pressed: Observable[DoorbellState]
+    on_siren_detected: Observable[SirenState]
+    on_battery_changed: Observable[BatteryState]
 
     async def snapshot(self, force_new: Optional[bool] = None) -> Optional[bytes]: ...
 
